.. _MsoThemeColorIndex:

``MSO_THEME_COLOR_INDEX``
=========================

Indicates the Office theme color, one of those shown in the color gallery on
the formatting ribbon.

Alias: ``MSO_THEME_COLOR``

Example::

    from docx.enum.dml import MSO_THEME_COLOR

    font.color.theme_color = MSO_THEME_COLOR.ACCENT_1

----

NOT_THEME_COLOR
    Indicates the color is not a theme color.

ACCENT_1
    Specifies the Accent 1 theme color.

ACCENT_2
    Specifies the Accent 2 theme color.

ACCENT_3
    Specifies the Accent 3 theme color.

ACCENT_4
    Specifies the Accent 4 theme color.

ACCENT_5
    Specifies the Accent 5 theme color.

ACCENT_6
    Specifies the Accent 6 theme color.

BACKGROUND_1
    Specifies the Background 1 theme color.

BACKGROUND_2
    Specifies the Background 2 theme color.

DARK_1
    Specifies the Dark 1 theme color.

DARK_2
    Specifies the Dark 2 theme color.

FOLLOWED_HYPERLINK
    Specifies the theme color for a clicked hyperlink.

HYPERLINK
    Specifies the theme color for a hyperlink.

LIGHT_1
    Specifies the Light 1 theme color.

LIGHT_2
    Specifies the Light 2 theme color.

TEXT_1
    Specifies the Text 1 theme color.

TEXT_2
    Specifies the Text 2 theme color.

MIXED
    Indicates multiple theme colors are used.
